==> graphviz-2.26.3-i486-1sl.txz: install/doinst.sh <==
#Configure dot plugins. 
/usr/bin/dot -c

( cd usr/man/man1 ; rm -rf fdp.1 )
( cd usr/man/man1 ; ln -sf dot.1 fdp.1 )
( cd usr/man/man1 ; rm -rf gv2gxl.1 )
( cd usr/man/man1 ; ln -sf gxl2gv.1 gv2gxl.1 )
( cd usr/man/man1 ; rm -rf twopi.1 )
( cd usr/man/man1 ; ln -sf dot.1 twopi.1 )
( cd usr/man/man1 ; rm -rf neato.1 )
( cd usr/man/man1 ; ln -sf dot.1 neato.1 )
( cd usr/man/man1 ; rm -rf circo.1 )
( cd usr/man/man1 ; ln -sf dot.1 circo.1 )
( cd usr/man/man1 ; rm -rf sfdp.1 )
( cd usr/man/man1 ; ln -sf dot.1 sfdp.1 )
( cd usr/share/php ; rm -rf gv.php )
( cd usr/share/php ; ln -sf /usr/lib/graphviz/php/gv.php gv.php )
( cd usr/lib/python2.6/site-packages ; rm -rf gv.py )
( cd usr/lib/python2.6/site-packages ; ln -sf /usr/lib/graphviz/python/gv.py gv.py )
( cd usr/lib/python2.6/site-packages ; rm -rf _gv.so )
( cd usr/lib/python2.6/site-packages ; ln -sf /usr/lib/graphviz/python/libgv_python.so _gv.so )
( cd usr/lib/ruby/site_ruby/1.9.1/i486-linux ; rm -rf gv.so )
( cd usr/lib/ruby/site_ruby/1.9.1/i486-linux ; ln -sf /usr/lib/graphviz/ruby/libgv_ruby.so gv.so )
( cd usr/lib/lua/5.1 ; rm -rf gv.so )
( cd usr/lib/lua/5.1 ; ln -sf /usr/lib/graphviz/lua/libgv_lua.so gv.so )
( cd usr/lib ; rm -rf libgvc.so )
( cd usr/lib ; ln -sf libgvc.so.5.0.0 libgvc.so )
( cd usr/lib/php/modules ; rm -rf gv.so )
( cd usr/lib/php/modules ; ln -sf /usr/lib/graphviz/php/libgv_php.so gv.so )
( cd usr/lib ; rm -rf libgvpr.so )
( cd usr/lib ; ln -sf libgvpr.so.1.0.0 libgvpr.so )
( cd usr/lib ; rm -rf libgvc.so.5 )
( cd usr/lib ; ln -sf libgvc.so.5.0.0 libgvc.so.5 )
( cd usr/lib ; rm -rf libgvpr.so.1 )
( cd usr/lib ; ln -sf libgvpr.so.1.0.0 libgvpr.so.1 )
( cd usr/lib/perl5/vendor_perl/5.10.1/i486-linux-thread-multi ; rm -rf gv.so )
( cd usr/lib/perl5/vendor_perl/5.10.1/i486-linux-thread-multi ; ln -sf /usr/lib/graphviz/perl/libgv_perl.so gv.so )
( cd usr/lib/perl5/vendor_perl/5.10.1/i486-linux-thread-multi ; rm -rf gv.pm )
( cd usr/lib/perl5/vendor_perl/5.10.1/i486-linux-thread-multi ; ln -sf /usr/lib/graphviz/perl/gv.pm gv.pm )
( cd usr/lib ; rm -rf libpathplan.so.4 )
( cd usr/lib ; ln -sf libpathplan.so.4.0.0 libpathplan.so.4 )
( cd usr/lib ; rm -rf libgraph.so.4 )
( cd usr/lib ; ln -sf libgraph.so.4.0.0 libgraph.so.4 )
( cd usr/lib ; rm -rf libxdot.so )
( cd usr/lib ; ln -sf libxdot.so.4.0.0 libxdot.so )
( cd usr/lib ; rm -rf libgraph.so )
( cd usr/lib ; ln -sf libgraph.so.4.0.0 libgraph.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gtk.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gtk.so.6.0.0 libgvplugin_gtk.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_dot_layout.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_dot_layout.so.6.0.0 libgvplugin_dot_layout.so.6 )
( cd usr/lib/graphviz/ruby ; rm -rf gv.so )
( cd usr/lib/graphviz/ruby ; ln -sf libgv_ruby.so gv.so )
( cd usr/lib/graphviz/lua ; rm -rf gv.so )
( cd usr/lib/graphviz/lua ; ln -sf libgv_lua.so gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_rsvg.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_rsvg.so.6.0.0 libgvplugin_rsvg.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gs.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gs.so.6.0.0 libgvplugin_gs.so )
( cd usr/lib/graphviz/php ; rm -rf gv.so )
( cd usr/lib/graphviz/php ; ln -sf libgv_php.so gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_xlib.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_xlib.so.6.0.0 libgvplugin_xlib.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_dot_layout.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_dot_layout.so.6.0.0 libgvplugin_dot_layout.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_pango.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_pango.so.6.0.0 libgvplugin_pango.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_core.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_core.so.6.0.0 libgvplugin_core.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_rsvg.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_rsvg.so.6.0.0 libgvplugin_rsvg.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_core.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_core.so.6.0.0 libgvplugin_core.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_xlib.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_xlib.so.6.0.0 libgvplugin_xlib.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gd.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gd.so.6.0.0 libgvplugin_gd.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_pango.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_pango.so.6.0.0 libgvplugin_pango.so.6 )
( cd usr/lib/graphviz/perl ; rm -rf gv.so )
( cd usr/lib/graphviz/perl ; ln -sf libgv_perl.so gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gdk_pixbuf.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gdk_pixbuf.so.6.0.0 libgvplugin_gdk_pixbuf.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gdk_pixbuf.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gdk_pixbuf.so.6.0.0 libgvplugin_gdk_pixbuf.so )
( cd usr/lib/graphviz/python ; rm -rf _gv.so )
( cd usr/lib/graphviz/python ; ln -sf libgv_python.so _gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gd.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gd.so.6.0.0 libgvplugin_gd.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gtk.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gtk.so.6.0.0 libgvplugin_gtk.so )
( cd usr/lib/graphviz/tcl ; rm -rf libgdtclft.so )
( cd usr/lib/graphviz/tcl ; ln -sf libgdtclft.so.0.0.0 libgdtclft.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot_builtin.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot_builtin.so.0.0.0 libtcldot_builtin.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot.so.0.0.0 libtcldot.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot_builtin.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot_builtin.so.0.0.0 libtcldot_builtin.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot.so.0.0.0 libtcldot.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtkspline.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtkspline.so.0.0.0 libtkspline.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtkspline.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtkspline.so.0.0.0 libtkspline.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtclplan.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtclplan.so.0.0.0 libtclplan.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libgdtclft.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libgdtclft.so.0.0.0 libgdtclft.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtclplan.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtclplan.so.0.0.0 libtclplan.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_neato_layout.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_neato_layout.so.6.0.0 libgvplugin_neato_layout.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gs.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gs.so.6.0.0 libgvplugin_gs.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_neato_layout.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_neato_layout.so.6.0.0 libgvplugin_neato_layout.so )
( cd usr/lib/tcl8.5 ; rm -rf graphviz )
( cd usr/lib/tcl8.5 ; ln -sf /usr/lib/graphviz/tcl graphviz )
( cd usr/lib ; rm -rf libxdot.so.4 )
( cd usr/lib ; ln -sf libxdot.so.4.0.0 libxdot.so.4 )
( cd usr/lib ; rm -rf libpathplan.so )
( cd usr/lib ; ln -sf libpathplan.so.4.0.0 libpathplan.so )
( cd usr/lib ; rm -rf libcgraph.so )
( cd usr/lib ; ln -sf libcgraph.so.5.0.0 libcgraph.so )
( cd usr/lib ; rm -rf libcdt.so )
( cd usr/lib ; ln -sf libcdt.so.4.0.0 libcdt.so )
( cd usr/lib ; rm -rf libcdt.so.4 )
( cd usr/lib ; ln -sf libcdt.so.4.0.0 libcdt.so.4 )
( cd usr/lib ; rm -rf libcgraph.so.5 )
( cd usr/lib ; ln -sf libcgraph.so.5.0.0 libcgraph.so.5 )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf gv2gxl.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf gxl2gv.1.pdf gv2gxl.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf sfdp.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf dot.1.pdf sfdp.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf fdp.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf dot.1.pdf fdp.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf circo.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf dot.1.pdf circo.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf twopi.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf dot.1.pdf twopi.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; rm -rf neato.1.pdf )
( cd usr/doc/graphviz-2.26.3/doc/pdf ; ln -sf dot.1.pdf neato.1.pdf )
( cd usr/bin ; rm -rf dot2gxl )
( cd usr/bin ; ln -sf gxl2gv dot2gxl )
( cd usr/bin ; rm -rf neato )
( cd usr/bin ; ln -sf dot neato )
( cd usr/bin ; rm -rf twopi )
( cd usr/bin ; ln -sf dot twopi )
( cd usr/bin ; rm -rf fdp )
( cd usr/bin ; ln -sf dot fdp )
( cd usr/bin ; rm -rf sfdp )
( cd usr/bin ; ln -sf dot sfdp )
( cd usr/bin ; rm -rf gxl2dot )
( cd usr/bin ; ln -sf gxl2gv gxl2dot )
( cd usr/bin ; rm -rf gv2gxl )
( cd usr/bin ; ln -sf gxl2gv gv2gxl )
( cd usr/bin ; rm -rf circo )
( cd usr/bin ; ln -sf dot circo )
( cd usr/bin ; rm -rf osage )
( cd usr/bin ; ln -sf dot osage )

==> graphviz-2.28.0-i486-2sl.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD|md5sum)" = "$(cat $NEW|md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/php/graphviz.ini.new

# Configure plugins
# (writes /usr/lib*/graphviz/config6 with available plugin information)
chroot . /usr/bin/dot -c
( cd usr/share/graphviz/doc/pdf ; rm -rf neato.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf dot.1.pdf neato.1.pdf )
( cd usr/share/graphviz/doc/pdf ; rm -rf gv2gxl.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf gxl2gv.1.pdf gv2gxl.1.pdf )
( cd usr/share/graphviz/doc/pdf ; rm -rf circo.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf dot.1.pdf circo.1.pdf )
( cd usr/share/graphviz/doc/pdf ; rm -rf twopi.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf dot.1.pdf twopi.1.pdf )
( cd usr/share/graphviz/doc/pdf ; rm -rf fdp.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf dot.1.pdf fdp.1.pdf )
( cd usr/share/graphviz/doc/pdf ; rm -rf sfdp.1.pdf )
( cd usr/share/graphviz/doc/pdf ; ln -sf dot.1.pdf sfdp.1.pdf )
( cd usr/share/php ; rm -rf gv.php )
( cd usr/share/php ; ln -sf /usr/lib/graphviz/php/gv.php gv.php )
( cd usr/man/man1 ; rm -rf neato.1.gz )
( cd usr/man/man1 ; ln -sf dot.1.gz neato.1.gz )
( cd usr/man/man1 ; rm -rf gv2gxl.1.gz )
( cd usr/man/man1 ; ln -sf gxl2gv.1.gz gv2gxl.1.gz )
( cd usr/man/man1 ; rm -rf sfdp.1.gz )
( cd usr/man/man1 ; ln -sf dot.1.gz sfdp.1.gz )
( cd usr/man/man1 ; rm -rf twopi.1.gz )
( cd usr/man/man1 ; ln -sf dot.1.gz twopi.1.gz )
( cd usr/man/man1 ; rm -rf fdp.1.gz )
( cd usr/man/man1 ; ln -sf dot.1.gz fdp.1.gz )
( cd usr/man/man1 ; rm -rf circo.1.gz )
( cd usr/man/man1 ; ln -sf dot.1.gz circo.1.gz )
( cd usr/bin ; rm -rf gxl2dot )
( cd usr/bin ; ln -sf gxl2gv gxl2dot )
( cd usr/bin ; rm -rf circo )
( cd usr/bin ; ln -sf dot circo )
( cd usr/bin ; rm -rf dot2gxl )
( cd usr/bin ; ln -sf gxl2gv dot2gxl )
( cd usr/bin ; rm -rf neato )
( cd usr/bin ; ln -sf dot neato )
( cd usr/bin ; rm -rf patchwork )
( cd usr/bin ; ln -sf dot patchwork )
( cd usr/bin ; rm -rf osage )
( cd usr/bin ; ln -sf dot osage )
( cd usr/bin ; rm -rf gv2gxl )
( cd usr/bin ; ln -sf gxl2gv gv2gxl )
( cd usr/bin ; rm -rf sfdp )
( cd usr/bin ; ln -sf dot sfdp )
( cd usr/bin ; rm -rf fdp )
( cd usr/bin ; ln -sf dot fdp )
( cd usr/bin ; rm -rf twopi )
( cd usr/bin ; ln -sf dot twopi )
( cd usr/lib ; rm -rf libcdt.so.5 )
( cd usr/lib ; ln -sf libcdt.so.5.0.0 libcdt.so.5 )
( cd usr/lib/lua/5.1 ; rm -rf gv.so )
( cd usr/lib/lua/5.1 ; ln -sf /usr/lib/graphviz/lua/libgv_lua.so gv.so )
( cd usr/lib ; rm -rf libgraph.so )
( cd usr/lib ; ln -sf libgraph.so.5.0.0 libgraph.so )
( cd usr/lib ; rm -rf libgvpr.so.2 )
( cd usr/lib ; ln -sf libgvpr.so.2.0.0 libgvpr.so.2 )
( cd usr/lib ; rm -rf libgraph.so.5 )
( cd usr/lib ; ln -sf libgraph.so.5.0.0 libgraph.so.5 )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot.so.0.0.0 libtcldot.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot.so.0.0.0 libtcldot.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtclplan.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtclplan.so.0.0.0 libtclplan.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libgdtclft.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libgdtclft.so.0.0.0 libgdtclft.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libgdtclft.so )
( cd usr/lib/graphviz/tcl ; ln -sf libgdtclft.so.0.0.0 libgdtclft.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtkspline.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtkspline.so.0.0.0 libtkspline.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot_builtin.so.0 )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot_builtin.so.0.0.0 libtcldot_builtin.so.0 )
( cd usr/lib/graphviz/tcl ; rm -rf libtcldot_builtin.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtcldot_builtin.so.0.0.0 libtcldot_builtin.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtkspline.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtkspline.so.0.0.0 libtkspline.so )
( cd usr/lib/graphviz/tcl ; rm -rf libtclplan.so )
( cd usr/lib/graphviz/tcl ; ln -sf libtclplan.so.0.0.0 libtclplan.so )
( cd usr/lib/graphviz/perl ; rm -rf gv.so )
( cd usr/lib/graphviz/perl ; ln -sf libgv_perl.so gv.so )
( cd usr/lib/graphviz/lua ; rm -rf gv.so )
( cd usr/lib/graphviz/lua ; ln -sf libgv_lua.so gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_xlib.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_xlib.so.6.0.0 libgvplugin_xlib.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gs.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gs.so.6.0.0 libgvplugin_gs.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_neato_layout.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_neato_layout.so.6.0.0 libgvplugin_neato_layout.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gtk.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gtk.so.6.0.0 libgvplugin_gtk.so )
( cd usr/lib/graphviz/python ; rm -rf _gv.so )
( cd usr/lib/graphviz/python ; ln -sf libgv_python.so _gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gdk_pixbuf.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gdk_pixbuf.so.6.0.0 libgvplugin_gdk_pixbuf.so.6 )
( cd usr/lib/graphviz/php ; rm -rf gv.so )
( cd usr/lib/graphviz/php ; ln -sf libgv_php.so gv.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_neato_layout.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_neato_layout.so.6.0.0 libgvplugin_neato_layout.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_rsvg.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_rsvg.so.6.0.0 libgvplugin_rsvg.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gs.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gs.so.6.0.0 libgvplugin_gs.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gdk_pixbuf.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gdk_pixbuf.so.6.0.0 libgvplugin_gdk_pixbuf.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_pango.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_pango.so.6.0.0 libgvplugin_pango.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_pango.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_pango.so.6.0.0 libgvplugin_pango.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_lasi.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_lasi.so.6.0.0 libgvplugin_lasi.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_dot_layout.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_dot_layout.so.6.0.0 libgvplugin_dot_layout.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gd.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gd.so.6.0.0 libgvplugin_gd.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_dot_layout.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_dot_layout.so.6.0.0 libgvplugin_dot_layout.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_core.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_core.so.6.0.0 libgvplugin_core.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_rsvg.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_rsvg.so.6.0.0 libgvplugin_rsvg.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gd.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gd.so.6.0.0 libgvplugin_gd.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_core.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_core.so.6.0.0 libgvplugin_core.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_lasi.so )
( cd usr/lib/graphviz ; ln -sf libgvplugin_lasi.so.6.0.0 libgvplugin_lasi.so )
( cd usr/lib/graphviz ; rm -rf libgvplugin_xlib.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_xlib.so.6.0.0 libgvplugin_xlib.so.6 )
( cd usr/lib/graphviz ; rm -rf libgvplugin_gtk.so.6 )
( cd usr/lib/graphviz ; ln -sf libgvplugin_gtk.so.6.0.0 libgvplugin_gtk.so.6 )
( cd usr/lib/php/extensions ; rm -rf gv.so )
( cd usr/lib/php/extensions ; ln -sf /usr/lib/graphviz/php/libgv_php.so gv.so )
( cd usr/lib/tcl8.5 ; rm -rf graphviz )
( cd usr/lib/tcl8.5 ; ln -sf /usr/lib/graphviz/tcl graphviz )
( cd usr/lib ; rm -rf libcgraph.so )
( cd usr/lib ; ln -sf libcgraph.so.6.0.0 libcgraph.so )
( cd usr/lib/perl5/vendor_perl ; rm -rf gv.so )
( cd usr/lib/perl5/vendor_perl ; ln -sf /usr/lib/graphviz/perl/libgv_perl.so gv.so )
( cd usr/lib/perl5/vendor_perl ; rm -rf gv.pm )
( cd usr/lib/perl5/vendor_perl ; ln -sf /usr/lib/graphviz/perl/gv.pm gv.pm )
( cd usr/lib ; rm -rf libgvc.so.6 )
( cd usr/lib ; ln -sf libgvc.so.6.0.0 libgvc.so.6 )
( cd usr/lib ; rm -rf libpathplan.so )
( cd usr/lib ; ln -sf libpathplan.so.4.0.0 libpathplan.so )
( cd usr/lib ; rm -rf libpathplan.so.4 )
( cd usr/lib ; ln -sf libpathplan.so.4.0.0 libpathplan.so.4 )
( cd usr/lib ; rm -rf libxdot.so.4 )
( cd usr/lib ; ln -sf libxdot.so.4.0.0 libxdot.so.4 )
( cd usr/lib ; rm -rf libcgraph.so.6 )
( cd usr/lib ; ln -sf libcgraph.so.6.0.0 libcgraph.so.6 )
( cd usr/lib/python2.7/site-packages ; rm -rf _gv.so )
( cd usr/lib/python2.7/site-packages ; ln -sf /usr/lib/graphviz/python/libgv_python.so _gv.so )
( cd usr/lib/python2.7/site-packages ; rm -rf gv.py )
( cd usr/lib/python2.7/site-packages ; ln -sf /usr/lib/graphviz/python/gv.py gv.py )
( cd usr/lib ; rm -rf libxdot.so )
( cd usr/lib ; ln -sf libxdot.so.4.0.0 libxdot.so )
( cd usr/lib ; rm -rf libgvc.so )
( cd usr/lib ; ln -sf libgvc.so.6.0.0 libgvc.so )
( cd usr/lib ; rm -rf libgvpr.so )
( cd usr/lib ; ln -sf libgvpr.so.2.0.0 libgvpr.so )
( cd usr/lib ; rm -rf libcdt.so )
( cd usr/lib ; ln -sf libcdt.so.5.0.0 libcdt.so )
